package com.ruoyi.buyerapi.service;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerDeptDevice;

/**
 * 企业信息管理设备Service接口
 * 
 * @author ruoyi
 * @date 2022-09-22
 */
public interface IBuyerDeptDeviceService 
{
    /**
     * 查询企业信息管理设备
     * 
     * @param id 企业信息管理设备主键
     * @return 企业信息管理设备
     */
    public BuyerDeptDevice selectBuyerDeptDeviceById(String id);

    /**
     * 查询企业信息管理设备列表
     * 
     * @param buyerDeptDevice 企业信息管理设备
     * @return 企业信息管理设备集合
     */
    public List<BuyerDeptDevice> selectBuyerDeptDeviceList(BuyerDeptDevice buyerDeptDevice);

    /**
     * 新增企业信息管理设备
     * 
     * @param buyerDeptDevice 企业信息管理设备
     * @return 结果
     */
    public int insertBuyerDeptDevice(BuyerDeptDevice buyerDeptDevice);

    /**
     * 修改企业信息管理设备
     * 
     * @param buyerDeptDevice 企业信息管理设备
     * @return 结果
     */
    public int updateBuyerDeptDevice(BuyerDeptDevice buyerDeptDevice);

    /**
     * 批量删除企业信息管理设备
     * 
     * @param ids 需要删除的企业信息管理设备主键集合
     * @return 结果
     */
    public int deleteBuyerDeptDeviceByIds(String[] ids);

    /**
     * 删除企业信息管理设备信息
     * 
     * @param id 企业信息管理设备主键
     * @return 结果
     */
    public int deleteBuyerDeptDeviceById(String id);
}
